RequestInput class
Constructors
-
RequestInput({required String path, Map<
String, String> headers = const {}, Map<String, dynamic> body = const {}, Map<String, dynamic> queryParam = const {}, HttpMethod request = HttpMethod.get}) -
const
Properties
-
body
→ Map<
String, dynamic> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
final
- path → String
-
final
-
queryParam
→ Map<
String, dynamic> -
final
- request → HttpMethod
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited